@@ -10,13 +10,15 @@ class Endpoint:
     2. read, signature:      get(data)
     2. update, signature: update(data, spec)
     3. delete, signature: delete(data)
-    5. list, signature:     list(limit, offset)
+    5. list, signature:     list(spec)
     """
 
     def __init__(self, endpoint,
-                 dummy=None):
+                 dummy=None,
+                 dependencies=None):
         self.endpoint = endpoint
         self.dummy = dummy
+        self.dependencies = dependencies if dependencies else []
 
     def call(self, *args, **kwargs):
         return self.endpoint(*args, **kwargs)
